@@ -1,10 +1,12 @@
 """This module provides entity classes to represent docstring structure."""
 from dataclasses import dataclass, field
-from typing import Any, Iterator, List, Optional
+from typing import Iterator, List, Optional
 
 import mkapi.core.preprocess
+from mkapi.core import linker
+from mkapi.core.preprocess import strip_ptags
+from mkapi.core.regex import LINK_PATTERN
 from mkapi.core.signature import Signature
-from mkapi.core.renderer import renderer
 
 
 @dataclass
@@ -13,38 +15,60 @@ class Base:
 
     Args:
         name: Object name.
-        type: Object type.
         markdown: Markdown source.
 
     Attributes:
         name: Object name.
-        type: Object type.
-        type_html: Object type html after adding links.
         markdown: Markdown source.
         html: HTML after conversion.
     """
 
-    name: str
-    type: str = ""
+    name: str = ""
     markdown: str = ""
     html: str = field(default="", init=False)
-    type_html: str = field(default="", init=False)
 
     def set_html(self, html: str):
-        """Sets `html` attribute."""
+        """Sets `html` attribute.
+
+        Args:
+            html: HTML string.
+        """
         self.html = html
 
 
+@dataclass
+class Type(Base):
+    """Type class represents type for other classes."""
+
+    def __post_init__(self):
+        if not self.markdown:
+            self.markdown = self.name
+
+    def __bool__(self):
+        return self.name != ""
+
+    def __iter__(self) -> Iterator[Base]:
+        if LINK_PATTERN.search(self.markdown):
+            yield self
+
+    def set_html(self, html: str):
+        """Sets `html` attribute cleaning `p` tags."""
+        self.html = strip_ptags(html)
+
+
 @dataclass
 class Item(Base):
     """Item class represents an item in Parameters, Attributes, and Raises sections."""
 
+    type: Type = field(default_factory=Type)
+
+    def __iter__(self) -> Iterator[Base]:
+        yield from self.type
+        yield self
+
     def set_html(self, html: str):
         """Sets `html` attribute cleaning `p` tags."""
-        html = html.replace("<p>", "").replace("</p>", "<br>")
-        if html.endswith("<br>"):
-            html = html[:-4]
-        self.html = html
+        self.html = strip_ptags(html)
 
 
 @dataclass
@@ -52,14 +76,14 @@ class Section(Base):
     """Section class represents a section in docstring.
 
     Args:
-        items: List for Arguments, Attributes, or Exceptions sections.
+        items: List for Arguments, Attributes, or Raises sections.
 
     Attributes:
-        items: List for Arguments, Attributes, or Exceptions sections.
+        items: List for Arguments, Attributes, or Raises sections.
 
     Examples:
         `Section` is iterable:
-        >>> section = Section('Returns', markdown='Returns an integer.')
+        >>> section = Section('Returns', markdown='An integer.')
         >>> for x in section:
         ...     assert x is section
 
@@ -80,12 +104,18 @@ class Section(Base):
     """
 
     items: List[Item] = field(default_factory=list)
+    type: Type = field(default_factory=Type)
+
+    def __post_init__(self):
+        if self.markdown:
+            self.markdown = mkapi.core.preprocess.convert(self.markdown)
 
     def __iter__(self) -> Iterator[Base]:
+        yield from self.type
         if self.markdown:
             yield self
-        else:
-            yield from self.items
+        for item in self.items:
+            yield from item
 
     def __getitem__(self, name) -> Optional[Item]:
         for item in self.items:
@@ -117,7 +147,7 @@ class Docstring:
         Docstring with 3 sections:
         >>> default = Section("", markdown="Default")
         >>> parameters = Section("Parameters", items=[Item("a"), Item("b")])
-        >>> returns = Section("Returns", markdown="Returned Value")
+        >>> returns = Section("Returns", markdown="Results")
         >>> docstring = Docstring([default, parameters, returns])
 
         `Docstring` is iterable:
@@ -130,12 +160,13 @@ class Docstring:
     """
 
     sections: List[Section] = field(default_factory=list)
-    type: str = ""
+    type: Type = field(default_factory=Type)
 
     def __bool__(self):
         return len(self.sections) > 0
 
     def __iter__(self) -> Iterator[Base]:
+        yield from self.type
         for section in self.sections:
             yield from section
 
@@ -160,72 +191,27 @@ class Docstring:
 
 
 @dataclass
-class Node(Base):
-    """Node class represents an object.
+class Object(Base):
+    """Object class represents an object."""
 
-    Attributes:
-        obj: Object.
-        depth: Current depth of object searching.
-        prefix: Prefix.
-        kind: Kind such as `function`, `class`, `module`, etc.
-        sourcefile: Souce filename thats defines this object.
-        lineno: Line number.
-        signature: Signature instance.
-        docstring: Docstring instance.
-        members: Member objects. For example, methods of class.
-        headless: Used in page mode.
-        html: HTML after rendering.
-    """
-
-    obj: Any = field(default=None, repr=False)
-    depth: int = 0
     prefix: str = ""
+    id: str = field(init=False)
     kind: str = ""
-    sourcefile: str = ""
-    lineno: int = 0
-    signature: Signature = field(default_factory=lambda: Signature())
-    docstring: Docstring = field(default_factory=lambda: Docstring())
-    members: List["Node"] = field(default_factory=list)
-    headless: bool = False
-    prefix_url: str = ""
-    name_url: str = ""
+    type: Type = field(default_factory=Type)
+    signature: Signature = field(default_factory=Signature)
 
     def __post_init__(self):
+        self.id = self.name
         if self.prefix:
             self.id = ".".join([self.prefix, self.name])
-        else:
-            self.id = self.name
-
-    def __getitem__(self, index):
-        return self.members[index]
-
-    def __len__(self):
-        return len(self.members)
-
-    def __getattr__(self, name):
-        for member in self.members:
-            if member.name == name:
-                return member
+        if not self.markdown:
+            name = linker.link(self.name, self.id)
+            if self.prefix:
+                prefix = linker.link(self.prefix, self.prefix)
+                self.markdown = ".".join([prefix, name])
+            else:
+                self.markdown = name
 
     def __iter__(self) -> Iterator[Base]:
-        if self.docstring:
-            yield from self.docstring
-        for member in self.members:
-            yield from member
-
-    def get_markdown(self) -> str:
-        """Returns a Markdown source for docstring of this object."""
-        markdowns = []
-        for base in self:
-            markdown = mkapi.core.preprocess.convert(base.markdown)
-            markdowns.append(markdown)
-        return "\n\n<!-- mkapi:sep -->\n\n".join(markdowns)
-
-    def set_html(self, html: str):
-        """Sets HTML to `Base` instances recursively."""
-        for base, html in zip(self, html.split("<!-- mkapi:sep -->")):
-            base.set_html(html.strip())
-
-    def render(self) -> str:
-        self.html = renderer.render(self)
-        return self.html
+        yield from self.type
+        yield self
